/**
 * Chemicals elements quiz
 *
 * @author Marc Oliveras <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2019 Oligalma
 * @license GPL License v3
 */

import java.awt.*;
import java.awt.event.*;
import java.text.DecimalFormat;
import java.util.Calendar;
import java.util.ResourceBundle;
import javax.swing.*;
import javax.swing.border.TitledBorder;

public class ChemicalElements extends JFrame implements Runnable 
{
	private static final long serialVersionUID = 1L;
	private int secondsPerQuestion;
	private int totalQuestions;
	private ResourceBundle bundle;
	private OptionsPanel optionsPanel = new OptionsPanel(this);
	private JOptionPane jOptionPane1 = new JOptionPane();
	private Thread counterThread = null;
	private String[] m1;
	private String[] m2 = {"H", "He", "Li", "Be", "B", "C", "N", "O", "F", "Ne", "Na", "Mg", "Al", "Si",
			"P", "S", "Cl", "Ar", "K", "Ca", "Sc", "Ti", "V", "Cr", "Mn", "Fe", "Co", "Ni", "Cu", "Zn",
			"Ga", "Ge", "As", "Se", "Br", "Kr", "Rb", "Sr", "Y", "Zr", "Nb", "Mo", "Tc", "Ru", "Rh",
			"Pd", "Ag", "Cd", "In", "Sn", "Sb", "Te", "I", "Xe", "Cs", "Ba", "La", "Ce", "Pr", "Nd",
			"Pm", "Sm", "Eu", "Gd", "Tb", "Dy", "Ho", "Er", "Tm", "Yb", "Lu", "Hf", "Ta", "W", "Re",
			"Os", "Ir", "Pt", "Au", "Hg", "Tl", "Pb", "Bi", "Po", "At", "Rn", "Fr", "Ra", "Ac", "Th",
			"Pa", "U", "Np", "Pu", "Am", "Cm", "Bk", "Cf", "Es", "Fm", "Md", "No", "Lr", "Rf", "Db",
			"Sg", "Bh", "Hs", "Mt", "Ds", "Rg", "Uub"};
	private boolean[] m3 = new boolean[112];
	private int appearedQuestions, randomQuestion, secondsLeft;
	private boolean stopButtonPressed, startButtonPressed = true, gameOver;
	private JTextField answerJTextField = new JTextField();
	private JLabel answerJLabel = new JLabel();
	private JLabel questionJLabel = new JLabel();
	private JLabel wrongJLabel = new JLabel();
	private JLabel right2JLabel = new JLabel();
	private JLabel wrong2JLabel = new JLabel();
	private JButton startStopJButton = new JButton();
	private JLabel element2JLabel = new JLabel();
	private JLabel elementJLabel = new JLabel();
	private JLabel modeJLabel = new JLabel();
	private JLabel element4JLabel = new JLabel();
	private JLabel symbol2JLabel = new JLabel();
	private JLabel element3JLabel = new JLabel();
	private JLabel symbolJLabel = new JLabel();
	private JLabel atomicNumber2JLabel = new JLabel();
	private JLabel atomicNumberJLabel = new JLabel();
	private JPanel correctAnswerJPanel = new JPanel();
	private JPanel scoreJPanel = new JPanel();
	private JLabel rightJLabel = new JLabel();
	private JMenuBar jMenuBar1 = new JMenuBar();
	private JMenu helpJMenu = new JMenu();
	private JMenuItem helpTopicsJMenuItem = new JMenuItem();
	private JMenuItem aboutJMenuItem = new JMenuItem();
	private JButton optionsJButton = new JButton();
	public JLabel timeJLabel = new JLabel();
	private JButton okJButton = new JButton();

	public ChemicalElements()
	{
		this.setDefaultCloseOperation(3);
		this.setTitle("Chemical elements quiz 1.0");
		this.setResizable(false);
		this.setSize(450, 300);
		Dimension d = Toolkit.getDefaultToolkit().getScreenSize();
		this.setLocation((d.width - this.getSize().width) / 2, (d.height - this.getSize().height) / 2);
		this.setVisible(true);
		
		JPanel contentPane = (JPanel) this.getContentPane();
		contentPane.setLayout(null);
		contentPane.setBackground(SystemColor.textHighlight);
		contentPane.setBackground(new Color(53, 190, 210));
		contentPane.setAlignmentY((float) 0.5);
		contentPane.setBorder(BorderFactory.createLineBorder(Color.black));
		contentPane.setDebugGraphicsOptions(0);
		contentPane.setToolTipText("");
		answerJTextField.setBackground(SystemColor.controlHighlight);
		answerJTextField.setFont(new java.awt.Font("Dialog", 1, 12));
		answerJTextField.setDebugGraphicsOptions(0);
		answerJTextField.setCaretColor(Color.black);
		answerJTextField.setEditable(false);
		answerJTextField.setFocusAccelerator(' ');
		answerJTextField.setText("");
		answerJTextField.setHorizontalAlignment(SwingConstants.CENTER);
		answerJTextField.setScrollOffset(0);
		answerJTextField.setBounds(new Rectangle(93, 87, 104, 27));
		answerJTextField.addKeyListener(new KeyListener() {
			public void keyPressed(KeyEvent e) {
				if (e.getKeyCode() == KeyEvent.VK_ENTER) {
					checkAnswer();
				}
			}
			public void keyReleased(KeyEvent e) {}
			public void keyTyped(KeyEvent e) {}
		});

		this.setLocale(java.util.Locale.getDefault());
		this.setJMenuBar(jMenuBar1);
		answerJLabel.setBorder(BorderFactory.createRaisedBevelBorder());
		answerJLabel.setFont(new java.awt.Font("Dialog", 0, 10));
		answerJLabel.setOpaque(true);
		answerJLabel.setHorizontalAlignment(SwingConstants.CENTER);
		answerJLabel.setBounds(new Rectangle(15, 88, 71, 27));
		questionJLabel.setBackground(new Color(203, 236, 197));
		questionJLabel.setFont(new java.awt.Font("Dialog", 1, 12));
		questionJLabel.setBorder(BorderFactory.createLineBorder(Color.black));
		questionJLabel.setOpaque(true);
		questionJLabel.setHorizontalAlignment(SwingConstants.CENTER);
		questionJLabel.setBounds(new Rectangle(93, 23, 335, 31));
		wrongJLabel.setBorder(null);
		wrongJLabel.setRequestFocusEnabled(true);
		wrongJLabel.setBounds(new Rectangle(12, 67, 88, 23));
		right2JLabel.setBackground(new Color(203, 236, 197));
		right2JLabel.setFont(new java.awt.Font("Dialog", 0, 20));
		right2JLabel.setBorder(BorderFactory.createLineBorder(Color.black));
		right2JLabel.setOpaque(true);
		right2JLabel.setRequestFocusEnabled(true);
		right2JLabel.setHorizontalAlignment(SwingConstants.CENTER);
		right2JLabel.setText("0");
		right2JLabel.setBounds(new Rectangle(98, 22, 41, 28));
		wrong2JLabel.setBackground(new Color(203, 236, 197));
		wrong2JLabel.setFont(new java.awt.Font("Dialog", 0, 20));
		wrong2JLabel.setBorder(BorderFactory.createLineBorder(Color.black));
		wrong2JLabel.setOpaque(true);
		wrong2JLabel.setHorizontalAlignment(SwingConstants.CENTER);
		wrong2JLabel.setText("0");
		wrong2JLabel.setBounds(new Rectangle(98, 62, 42, 28));
		startStopJButton.setBackground(Color.lightGray);
		startStopJButton.setBounds(new Rectangle(279, 72, 104, 43));
		startStopJButton.setFont(new java.awt.Font("Dialog", 1, 12));
		startStopJButton.setForeground(Color.black);
		startStopJButton.setOpaque(true);
		startStopJButton.setMargin(new Insets(2, 2, 2, 2));
		startStopJButton.setSelected(true);
		startStopJButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				startStop();				
			}
		});
		element2JLabel.setBackground(new Color(203, 236, 197));
		element2JLabel.setFont(new java.awt.Font("Dialog", 1, 12));
		element2JLabel.setAlignmentX((float) 0.0);
		element2JLabel.setBorder(BorderFactory.createLineBorder(Color.black));
		element2JLabel.setOpaque(true);
		element2JLabel.setRequestFocusEnabled(true);
		element2JLabel.setHorizontalAlignment(SwingConstants.CENTER);
		element2JLabel.setText("???");
		element2JLabel.setBounds(new Rectangle(93, 56, 170, 29));
		elementJLabel.setFont(new java.awt.Font("Dialog", 0, 10));
		elementJLabel.setBorder(BorderFactory.createRaisedBevelBorder());
		elementJLabel.setOpaque(true);
		elementJLabel.setPreferredSize(new Dimension(56, 16));
		elementJLabel.setHorizontalAlignment(SwingConstants.CENTER);
		elementJLabel.setBounds(new Rectangle(15, 57, 71, 27));
		modeJLabel.setFont(new java.awt.Font("Dialog", 0, 10));
		modeJLabel.setBorder(BorderFactory.createRaisedBevelBorder());
		modeJLabel.setOpaque(true);
		modeJLabel.setRequestFocusEnabled(true);
		modeJLabel.setHorizontalAlignment(SwingConstants.CENTER);
		modeJLabel.setBounds(new Rectangle(16, 24, 70, 28));
		element4JLabel.setBackground(new Color(203, 236, 197));
		element4JLabel.setFont(new java.awt.Font("Dialog", 1, 12));
		element4JLabel.setBorder(BorderFactory.createLineBorder(Color.black));
		element4JLabel.setOpaque(true);
		element4JLabel.setRequestFocusEnabled(true);
		element4JLabel.setHorizontalAlignment(SwingConstants.CENTER);
		element4JLabel.setText("???");
		element4JLabel.setBounds(new Rectangle(104, 18, 135, 21));
		symbol2JLabel.setText("???");
		symbol2JLabel.setBounds(new Rectangle(104, 48, 135, 22));
		symbol2JLabel.setBackground(new Color(203, 236, 197));
		symbol2JLabel.setFont(new java.awt.Font("Dialog", 1, 12));
		symbol2JLabel.setBorder(BorderFactory.createLineBorder(Color.black));
		symbol2JLabel.setOpaque(true);
		symbol2JLabel.setRequestFocusEnabled(true);
		symbol2JLabel.setHorizontalAlignment(SwingConstants.CENTER);
		element3JLabel.setFont(new java.awt.Font("Dialog", 2, 12));
		element3JLabel.setBounds(new Rectangle(12, 18, 80, 19));
		symbolJLabel.setBounds(new Rectangle(12, 49, 80, 19));
		symbolJLabel.setFont(new java.awt.Font("Dialog", 2, 12));
		atomicNumber2JLabel.setBackground(new Color(203, 236, 197));
		atomicNumber2JLabel.setFont(new java.awt.Font("Dialog", 1, 12));
		atomicNumber2JLabel.setBorder(BorderFactory.createLineBorder(Color.black));
		atomicNumber2JLabel.setOpaque(true);
		atomicNumber2JLabel.setRequestFocusEnabled(true);
		atomicNumber2JLabel.setHorizontalAlignment(SwingConstants.CENTER);
		atomicNumber2JLabel.setText("???");
		atomicNumber2JLabel.setBounds(new Rectangle(104, 78, 135, 20));
		atomicNumberJLabel.setFont(new java.awt.Font("Dialog", 2, 12));
		atomicNumberJLabel.setOpaque(false);
		atomicNumberJLabel.setRequestFocusEnabled(true);
		atomicNumberJLabel.setBounds(new Rectangle(12, 77, 91, 21));
		correctAnswerJPanel.setBounds(new Rectangle(16, 127, 251, 105));
		correctAnswerJPanel.setLayout(null);
		scoreJPanel.setOpaque(false);
		scoreJPanel.setBounds(new Rectangle(279, 127, 148, 105));
		scoreJPanel.setLayout(null);
		rightJLabel.setRequestFocusEnabled(true);
		rightJLabel.setBounds(new Rectangle(12, 30, 89, 17));
		helpJMenu.setBorder(null);
		helpTopicsJMenuItem.setBorder(null);
		helpTopicsJMenuItem.setText("Help Topics");
		aboutJMenuItem.setBorder(null);
		aboutJMenuItem.setText("About...");
		optionsJButton.setFont(new java.awt.Font("SansSerif", 1, 11));
		optionsJButton.setFocusPainted(false);
		optionsJButton.setMargin(new Insets(2, 14, 2, 14));
		jMenuBar1.setBorder(BorderFactory.createLineBorder(Color.black));
		jOptionPane1.setBorder(BorderFactory.createEtchedBorder());
		okJButton.setEnabled(false);
		okJButton.setFont(new java.awt.Font("Dialog", 1, 15));
		okJButton.setMinimumSize(new Dimension(37, 23));
		okJButton.setMargin(new Insets(2, 2, 2, 2));
		okJButton.setMnemonic('0');
		okJButton.setText("OK");
		okJButton.setBounds(new Rectangle(202, 87, 38, 28));
		okJButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				checkAnswer();
			}
		});
		contentPane.add(modeJLabel, null);
		contentPane.add(correctAnswerJPanel, null);
		correctAnswerJPanel.setOpaque(false);
		correctAnswerJPanel.add(element3JLabel, null);
		correctAnswerJPanel.add(atomicNumber2JLabel, null);
		correctAnswerJPanel.add(symbol2JLabel, null);
		correctAnswerJPanel.add(element4JLabel, null);
		correctAnswerJPanel.add(symbolJLabel, null);
		correctAnswerJPanel.add(atomicNumberJLabel, null);
		contentPane.add(scoreJPanel, null);
		scoreJPanel.add(right2JLabel, null);
		scoreJPanel.add(wrong2JLabel, null);
		scoreJPanel.add(rightJLabel, null);
		scoreJPanel.add(wrongJLabel, null);
		contentPane.add(elementJLabel, null);
		contentPane.add(answerJLabel, null);
		contentPane.add(questionJLabel, null);
		contentPane.add(element2JLabel, null);
		contentPane.add(answerJTextField, null);
		contentPane.add(startStopJButton, null);
		contentPane.add(okJButton, null);
		timeJLabel.setBounds(389, 82, 39, 31);
		getContentPane().add(timeJLabel);
		timeJLabel.setBackground(new Color(203, 236, 197));
		timeJLabel.setEnabled(true);
		timeJLabel.setFont(new Font("Dialog", Font.BOLD, 23));
		timeJLabel.setBorder(BorderFactory.createLineBorder(Color.black));
		timeJLabel.setOpaque(true);
		timeJLabel.setPreferredSize(new Dimension(16, 18));
		timeJLabel.setRequestFocusEnabled(true);
		timeJLabel.setHorizontalAlignment(SwingConstants.CENTER);
		timeJLabel.setText("10");
		optionsJButton.setBorder(null);
		jMenuBar1.add(optionsJButton);
		jMenuBar1.add(helpJMenu);
		helpJMenu.add(helpTopicsJMenuItem);
		helpJMenu.add(aboutJMenuItem);
		helpTopicsJMenuItem.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				showHelp();				
			}
		});
		aboutJMenuItem.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				showAbout();
			}
		});
		optionsJButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				optionsPanel.showOptions();
				
				
			}
		});
		
		totalQuestions = Integer.parseInt(optionsPanel.getQuestionsNumberJTextField().getText());
		secondsPerQuestion = Integer.parseInt(optionsPanel.getSecondsJTextField().getText());
		
		Utils.getProperties().setProperty("language","en_US");
		Utils.getProperties().setProperty("mode","1");
		Utils.getProperties().setProperty("seconds","10");
		Utils.getProperties().setProperty("questions","20");
		Utils.getProperties().setProperty("allow_blank_answers","true");
		Utils.getProperties().setProperty("show_correct_answers","true");
		Utils.getProperties().setProperty("seconds_enabled", "true");
		
		changeLanguage();
	}

	public static void main(String[] args) {
		new ChemicalElements();
	}
	
	private void showHelp() {
		
		String message = "Chemical elements is a magnificent program to learn the names of the "
						+ "chemical elements, its symbols and its atomic numbers."
						+ "\n\nThere are 4 modes."
						+ "\n\nIn the mode 1 the name of the chemical element is shown "
						+ "and you need to type its symbol.\n\nIn the mode 2 the symbol is shown "
						+ "and you need to type the name.\n\nIn the mode 3 the name and symbol are shown "
						+ "and you need to type the atomic number "
						+ "\n\nFinally, in the mode 4, the atomic number is shown "
						+ "and you need to type the name or the symbol (both options are valid).";
		
		JOptionPane.showMessageDialog(this, message, "Help topics", JOptionPane.PLAIN_MESSAGE);
	}

	private void startStop() {
		gameOver = false;
		optionsJButton.setEnabled(true);
		element4JLabel.setText("???");
		symbol2JLabel.setText("???");
		atomicNumber2JLabel.setText("???");
		element2JLabel.setText("???");
		startStopJButton.setText(bundle.getString("start"));
		if (stopButtonPressed == true)
			startButtonPressed = true;
		appearedQuestions = 0;
		answerJTextField.setEditable(false);
		right2JLabel.setText("0");
		wrong2JLabel.setText("0");
		answerJTextField.setText("");
		okJButton.setEnabled(false);

		
		if (startButtonPressed)
		{
			if(optionsPanel.secondsJCheckBox.isSelected())
			{
				counterThread = new Thread(this);
				counterThread.start();
			}
			startButtonPressed = false;
			stopButtonPressed = false;
			startStopJButton.setText(bundle.getString("stop"));
			optionsJButton.setEnabled(false);
			okJButton.setEnabled(true);
			answerJTextField.setEditable(true);
			m3 = new boolean[112];
			newQuestion();
		} 
		else
		{
			stopButtonPressed = true;
		}
	}

	private void checkAnswer() {
		String answer = answerJTextField.getText().toUpperCase();
		if (answer.equals("") && !optionsPanel.blankAnswersJCheckBox.isSelected() && secondsLeft > 0)
			JOptionPane.showMessageDialog(this, bundle.getString("type_the_answer"), "Oops",
					JOptionPane.INFORMATION_MESSAGE);
		else {
			secondsLeft = secondsPerQuestion;
			boolean answeredCorrectly = false;
			if (optionsPanel.mode1RadioButton.isSelected()) {
				if (m2[randomQuestion].toUpperCase().equals(answer))
					answeredCorrectly = true;
			} else if (optionsPanel.mode2RadioButton.isSelected()) {
				if (m1[randomQuestion].toUpperCase().equals(answer))
					answeredCorrectly = true;
			} else if (optionsPanel.mode3RadioButton.isSelected()) {
				if (Integer.toString(randomQuestion + 1).equals(answer))
					answeredCorrectly = true;
			} else {
				if (m1[randomQuestion].toUpperCase().equals(answer) 
						|| m2[randomQuestion].toUpperCase().equals(answer))
					answeredCorrectly = true;
			}

			if (answeredCorrectly)
				right2JLabel.setText(Integer.toString(Integer.parseInt(right2JLabel.getText()) + 1));
			else
				wrong2JLabel.setText(Integer.toString(Integer.parseInt(wrong2JLabel.getText()) + 1));

			if (optionsPanel.mode1RadioButton.isSelected()) {
				element4JLabel.setText(m1[randomQuestion]);
				atomicNumber2JLabel.setText(Integer.toString(randomQuestion + 1));
			} else if (optionsPanel.mode2RadioButton.isSelected()) {
				symbol2JLabel.setText(m2[randomQuestion]);
				atomicNumber2JLabel.setText(Integer.toString(randomQuestion + 1));
			} else if (optionsPanel.mode3RadioButton.isSelected()) {
				symbol2JLabel.setText(m2[randomQuestion]);
				element4JLabel.setText(m1[randomQuestion]);
			} else
				atomicNumber2JLabel.setText(Integer.toString(randomQuestion + 1));

			if (optionsPanel.showCorrectAnswersJCheckBox.isSelected()) {
				if (optionsPanel.mode1RadioButton.isSelected())
					symbol2JLabel.setText(m2[randomQuestion]);
				else if (optionsPanel.mode2RadioButton.isSelected())
					element4JLabel.setText(m1[randomQuestion]);
				else if (optionsPanel.mode3RadioButton.isSelected())
					atomicNumber2JLabel.setText(Integer.toString(randomQuestion + 1));
				else {
					element4JLabel.setText(m1[randomQuestion]);
					symbol2JLabel.setText(m2[randomQuestion]);
				}
			} else {
				if (optionsPanel.mode1RadioButton.isSelected()) {
					symbol2JLabel.setText("???");
				} else if (optionsPanel.mode2RadioButton.isSelected()) {
					element4JLabel.setText("???");
				} else if (optionsPanel.mode3RadioButton.isSelected()) {
					atomicNumber2JLabel.setText("???");
				} else {
					element4JLabel.setText("???");
					symbol2JLabel.setText("???");
				}
			}		
			newQuestion();
		}
	}

	private void showAbout() {
		JOptionPane
				.showMessageDialog(
						this,
						"CHEMICAL ELEMENTS QUIZ 1.0\n\nby Marc Oliveras, " + Calendar.getInstance().get(Calendar.YEAR) + ". All rights reserved.\n\nadmin@oligalma.com\n\nhttp://www.oligalma.com",
						"About...", JOptionPane.INFORMATION_MESSAGE);
	}
	
	private void newQuestion() {
		if (totalQuestions > appearedQuestions) {
			appearedQuestions++;
			
			for (;;) {
				randomQuestion = (int) (Math.random() * m1.length);
				if (m3[randomQuestion] == false) {
					m3[randomQuestion] = true;
					break;
				}
			}
			if (optionsPanel.mode1RadioButton.isSelected())
				element2JLabel.setText(m1[randomQuestion]);
			else if (optionsPanel.mode2RadioButton.isSelected())
				element2JLabel.setText(m2[randomQuestion]);
			else if (optionsPanel.mode3RadioButton.isSelected())
				element2JLabel.setText(m1[randomQuestion] + " / " + m2[randomQuestion]);
			else
				element2JLabel.setText(Integer.toString(randomQuestion + 1));

			answerJTextField.setText("");
			answerJTextField.requestFocus();
		} else {
			gameOver = true;
			this.requestFocus();
			okJButton.setEnabled(false);
			optionsJButton.setEnabled(true);
			answerJTextField.setEditable(false);
			startButtonPressed = true;
			startStopJButton.setText(bundle.getString("start"));
			
			float score = 10 * Float.parseFloat(right2JLabel.getText()) / totalQuestions;		
			String message;
			
			if (score == 0)
				message = bundle.getString("you_hit_rock_bottom");
			else if (score > 0 && score <= 2)
				message = bundle.getString("really_bad");
			else if (score > 2 && score < 5)
				message = bundle.getString("slightly_bad");
			else if (score >= 5 && score < 7)
				message = bundle.getString("good");
			else if (score >= 7 && score < 9)
				message = bundle.getString("very_good");
			else if (score >= 9 && score < 10)
				message = bundle.getString("amazing");
			else
				message = bundle.getString("perfect");
			
			DecimalFormat df = new DecimalFormat("0.00");
			 
			JOptionPane.showMessageDialog(this, bundle.getString("score") + ": " + df.format(score) + 
					". " + message.toUpperCase() + ".", "Game Over", JOptionPane.INFORMATION_MESSAGE);
		}
	}
	
	public void run()
	{
		while (!gameOver && !stopButtonPressed) {
			timeJLabel.setText(Integer.toString(secondsPerQuestion));
			
			for (secondsLeft = secondsPerQuestion; secondsLeft >= 0; secondsLeft--) {
				try {
					Thread.sleep(1000);
				} catch (InterruptedException e) {}
				
				if(gameOver || stopButtonPressed)
					break;
				
				timeJLabel.setText(Integer.toString(secondsLeft));
			}
			if(!gameOver && !stopButtonPressed)
				checkAnswer();			
		}
		
		timeJLabel.setText(Integer.toString(secondsPerQuestion));
	}
	
	public void changeLanguage()
	{
		bundle = Utils.getBundle();

		m1 = new String[112];
		
		m1[0] = bundle.getString("hydrogen"); m1[1] = bundle.getString("helium");
		m1[2] = bundle.getString("lithium"); m1[3] = bundle.getString("beryllium");		
		m1[4] = bundle.getString("boron"); m1[5] = bundle.getString("carbon");
		m1[6] = bundle.getString("nitrogen"); m1[7] =	bundle.getString("oxygen");
		m1[8] = bundle.getString("fluorine"); m1[9] = bundle.getString("neon");
		m1[10] = bundle.getString("sodium"); m1[11] = bundle.getString("magnesium");
		m1[12] = bundle.getString("aluminum"); m1[13] = bundle.getString("silicon");
		m1[14] = bundle.getString("phosphorus"); m1[15] = bundle.getString("sulfur");
		m1[16] = bundle.getString("chlorine"); m1[17] = bundle.getString("argon");
		m1[18] = bundle.getString("potassium"); m1[19] = bundle.getString("calcium");
		m1[20] = bundle.getString("scandium"); m1[21] = bundle.getString("titanium");
		m1[22] = bundle.getString("vanadium"); m1[23] = bundle.getString("chromium");
		m1[24] = bundle.getString("manganese"); m1[25] = bundle.getString("iron");
		m1[26] = bundle.getString("cobalt"); m1[27] = bundle.getString("nickel");
		m1[28] = bundle.getString("copper"); m1[29] = bundle.getString("zinc");
		m1[30] = bundle.getString("gallium"); m1[31] = bundle.getString("germanium");
		m1[32] = bundle.getString("arsenic"); m1[33] = bundle.getString("selenium");
		m1[34] = bundle.getString("bromine"); m1[35] = bundle.getString("krypton");
		m1[36] = bundle.getString("rubidium"); m1[37] = bundle.getString("strontium");
		m1[38] = bundle.getString("yttrium"); m1[39] = bundle.getString("zirconium");	
		m1[40] = bundle.getString("niobium"); m1[41] = bundle.getString("molybdenum");
		m1[42] = bundle.getString("technetium"); m1[43] = bundle.getString("ruthenium");
		m1[44] = bundle.getString("rhodium"); m1[45] = bundle.getString("palladium");
		m1[46] = bundle.getString("silver"); m1[47] = bundle.getString("cadmium");
		m1[48] = bundle.getString("indium"); m1[49] = bundle.getString("tin");		
		m1[50] = bundle.getString("antimony"); m1[51] = bundle.getString("tellurium");
		m1[52] = bundle.getString("iodine"); m1[53] = bundle.getString("xenon");
		m1[54] = bundle.getString("cesium"); m1[55] = bundle.getString("barium");
		m1[56] = bundle.getString("lanthanum"); m1[57] = bundle.getString("cerium");
		m1[58] = bundle.getString("praseodymium"); m1[59] = bundle.getString("neodymium");	
		m1[60] = bundle.getString("promethium"); m1[61] = bundle.getString("samarium");
		m1[62] = bundle.getString("europium"); m1[63] = bundle.getString("gadolinium");
		m1[64] = bundle.getString("terbium"); m1[65] = bundle.getString("dysprosium");
		m1[66] = bundle.getString("holmium"); m1[67] = bundle.getString("erbium");
		m1[68] = bundle.getString("thulium"); m1[69] = bundle.getString("ytterbium");	
		m1[70] = bundle.getString("lutetium"); m1[71] = bundle.getString("hafnium");
		m1[72] = bundle.getString("tantalum"); m1[73] = bundle.getString("tungsten");
		m1[74] = bundle.getString("rhenium"); m1[75] = bundle.getString("osmium");		
		m1[76] = bundle.getString("iridium"); m1[77] = bundle.getString("platinum");
		m1[78] = bundle.getString("gold"); m1[79] = bundle.getString("mercury");
		m1[80] = bundle.getString("thallium"); m1[81] = bundle.getString("lead");
		m1[82] = bundle.getString("bismuth"); m1[83] = bundle.getString("polonium");
		m1[84] = bundle.getString("astatine"); m1[85] = bundle.getString("radon");
		m1[86] = bundle.getString("francium"); m1[87] = bundle.getString("radium");
		m1[88] = bundle.getString("actinium"); m1[89] = bundle.getString("thorium");
		m1[90] = bundle.getString("protactinium"); m1[91] = bundle.getString("uranium");
		m1[92] = bundle.getString("neptunium"); m1[93] = bundle.getString("plutonium");
		m1[94] = bundle.getString("americium"); m1[95] = bundle.getString("curium");
		m1[96] = bundle.getString("berkelium"); m1[97] = bundle.getString("californium");
		m1[98] = bundle.getString("einsteinium"); m1[99] = bundle.getString("fermium");		
		m1[100] = bundle.getString("mendelevium"); m1[101] = bundle.getString("nobelium");
		m1[102] = bundle.getString("lawrencium"); m1[103] = bundle.getString("rutherfordium");
		m1[104] = bundle.getString("dubnium"); m1[105] = bundle.getString("seaborgium");
		m1[106] = bundle.getString("bohrium"); m1[107] = bundle.getString("hassium");
		m1[108] = bundle.getString("meitnerium"); m1[109] = bundle.getString("darmstadtium");	
		m1[110] = bundle.getString("roentgenium"); m1[111] = bundle.getString("ununbium");
		
		questionJLabel.setText(bundle.getString("which_is_the_symbol_of_this_element"));
		modeJLabel.setText(bundle.getString("mode").toUpperCase());
		elementJLabel.setText(bundle.getString("element").toUpperCase());
		element3JLabel.setText(bundle.getString("element"));
		answerJLabel.setText(bundle.getString("answer"));
		startStopJButton.setText(bundle.getString("start"));
		rightJLabel.setText(bundle.getString("right"));
		wrongJLabel.setText(bundle.getString("wrong"));
		optionsJButton.setText(" " + bundle.getString("options") + " ");
		helpJMenu.setText(bundle.getString("help"));
		symbolJLabel.setText(bundle.getString("symbol"));
		atomicNumberJLabel.setText(bundle.getString("atomic_number"));
		correctAnswerJPanel.setBorder(new TitledBorder(null, bundle.getString("correct_answer"), TitledBorder.LEADING, TitledBorder.TOP, null, null));
		scoreJPanel.setBorder(new TitledBorder(null, bundle.getString("score"), TitledBorder.LEADING, TitledBorder.TOP, null, null));
	}
	
	public void setQuestionJLabelText(String text) {
		this.questionJLabel.setText(text);
	}

	public void setElementJLabelText(String text) {
		this.elementJLabel.setText(text);
	}

	public void setSecondsPerQuestion(int secondsPerQuestion) {
		this.secondsPerQuestion = secondsPerQuestion;
	}

	public void setTotalQuestions(int totalQuestions) {
		this.totalQuestions = totalQuestions;
	}
}
