/**
 * Chemicals elements quiz
 *
 * @author Marc Oliveras <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2019 Oligalma
 * @license GPL License v3
 */

import java.awt.*;
import java.awt.event.*;
import java.util.Locale;
import java.util.ResourceBundle;
import javax.swing.*;

public class OptionsPanel extends JPanel
{
	private static final long serialVersionUID = 1L;
	private ChemicalElements applet;
	private JPanel jPanel8 = new JPanel();
	private JTextField secondsJTextField = new JTextField();
	private JPanel jPanel5 = new JPanel();
	public JRadioButton mode1RadioButton = new JRadioButton();
	public JRadioButton mode2RadioButton = new JRadioButton();
	public JRadioButton mode3RadioButton = new JRadioButton();
	public JRadioButton mode4RadioButton = new JRadioButton();
	private ButtonGroup buttonGroup1 = new ButtonGroup();
	private JTextField questionsNumberJTextField = new JTextField();
	public JCheckBox secondsJCheckBox = new JCheckBox();
	private JLabel questionsNumberJLabel = new JLabel();
	public JCheckBox showCorrectAnswersJCheckBox = new JCheckBox();
	public JCheckBox blankAnswersJCheckBox = new JCheckBox();
	private JComboBox<String> languagesJComboBox;
	private ResourceBundle bundle;
	
	public OptionsPanel(final ChemicalElements applet)
	{
		this.applet = applet;
		this.setLayout(null);
		this.setBounds(new Rectangle(38, 252, 326, 113));
		this.setVerifyInputWhenFocusTarget(false);
		this.setOpaque(true);
		this.setPreferredSize(new Dimension(360, 187));
		this.setToolTipText("");
		this.setDebugGraphicsOptions(0);
		this.setMaximumSize(new Dimension(32767, 32767));
		this.setMinimumSize(new Dimension(1, 1));
		this.setBorder(BorderFactory.createEtchedBorder());
		secondsJCheckBox.setSelected(true);
		secondsJCheckBox.setBounds(new Rectangle(8, 28, 214, 24));
		jPanel8.setLayout(null);
		jPanel8.setBounds(new Rectangle(7, 12, 341, 109));
		jPanel8.add(secondsJTextField, null);
		jPanel8.add(secondsJCheckBox, null);
		this.add(jPanel8, null);
		secondsJTextField.setBackground(new Color(203, 236, 197));
		secondsJTextField.setPreferredSize(new Dimension(30, 22));
		secondsJTextField.setSelectionStart(2);
		secondsJTextField.setOpaque(true);
		secondsJTextField.setText("10");
		secondsJTextField.setBounds(new Rectangle(230, 30, 30, 22));
		secondsJTextField.setEnabled(true);
		blankAnswersJCheckBox.setSelected(true);
		blankAnswersJCheckBox.setBounds(8, 77, 240, 32);
		jPanel8.add(blankAnswersJCheckBox);
		blankAnswersJCheckBox.setOpaque(false);
		showCorrectAnswersJCheckBox.setBounds(8, 52, 240, 28);
		jPanel8.add(showCorrectAnswersJCheckBox);
		showCorrectAnswersJCheckBox.setSelected(true);
		showCorrectAnswersJCheckBox.setOpaque(false);
		questionsNumberJLabel.setBounds(8, 4, 214, 16);
		jPanel8.add(questionsNumberJLabel);
		questionsNumberJLabel.setRequestFocusEnabled(true);
		questionsNumberJLabel.setBorder(null);
		questionsNumberJTextField.setBounds(230, 4, 30, 22);
		jPanel8.add(questionsNumberJTextField);
		questionsNumberJTextField.setText("20");
		questionsNumberJTextField.setOpaque(true);
		questionsNumberJTextField.setPreferredSize(new Dimension(30, 22));
		questionsNumberJTextField.setBackground(new Color(203, 236, 197));
		
		jPanel5.setLayout(null);
		jPanel5.setBounds(new Rectangle(7, 117, 341, 34));
		jPanel5.add(mode1RadioButton, null);
		jPanel5.add(mode2RadioButton, null);
		jPanel5.add(mode3RadioButton, null);
		jPanel5.add(mode4RadioButton, null);
		this.add(jPanel5, null);
		
		mode1RadioButton.setBounds(new Rectangle(8, 5, 80, 25));
		mode1RadioButton.setSelected(true);
		mode1RadioButton.setOpaque(false);	
		mode2RadioButton.setText("Mode 2");
		mode2RadioButton.setBounds(new Rectangle(85, 5, 80, 25));
		mode2RadioButton.setOpaque(false);
		mode3RadioButton.setText("Mode 3");
		mode3RadioButton.setBounds(new Rectangle(164, 5, 80, 25));
		mode3RadioButton.setOpaque(false);
		mode4RadioButton.setText("Mode 4");
		mode4RadioButton.setBounds(new Rectangle(242, 5, 80, 25));
		mode4RadioButton.setOpaque(false);
		
		buttonGroup1.add(mode4RadioButton);
		buttonGroup1.add(mode3RadioButton);
		buttonGroup1.add(mode2RadioButton);
		buttonGroup1.add(mode1RadioButton);	
		
		languagesJComboBox = new JComboBox<String>();
		languagesJComboBox.setBounds(120, 155, 111, 24);
		languagesJComboBox.addItem("Català");
		languagesJComboBox.addItem("English");
		languagesJComboBox.addItem("Español");
		languagesJComboBox.addItem("Français");
		languagesJComboBox.setSelectedIndex(1);
		languagesJComboBox.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {				
				if(languagesJComboBox.getSelectedIndex() == 0)
					Locale.setDefault(new Locale("ca", "ES"));
				else if(languagesJComboBox.getSelectedIndex() == 1)
					Locale.setDefault(new Locale("en", "US"));
				else if(languagesJComboBox.getSelectedIndex() == 2)
					Locale.setDefault(new Locale("es", "ES"));
				else if(languagesJComboBox.getSelectedIndex() == 3)
					Locale.setDefault(new Locale("fr", "FR"));
				
				applet.changeLanguage();
				changeLanguage();
			}
		});
		add(languagesJComboBox);
		
		changeLanguage();
	}
	
	public void showOptions()
	{
		boolean allOptionsRight;
		int questionsNumber = 0;
		int seconds = 0;
		
		do
		{		
			allOptionsRight = true;

			JOptionPane.showMessageDialog(applet, this, "Options", JOptionPane.PLAIN_MESSAGE);
			
			try {
				questionsNumber = Integer.parseInt(questionsNumberJTextField.getText());
				seconds = Integer.parseInt(secondsJTextField.getText());
				
				if (questionsNumber < 1 || questionsNumber > 112) {
					JOptionPane.showMessageDialog(this,
							bundle.getString("type_a_value_between") + " [1-112]", "Oops",
							JOptionPane.ERROR_MESSAGE);
					allOptionsRight = false;
				} else if (seconds < 1 || seconds > 60) {
					JOptionPane.showMessageDialog(this,
							bundle.getString("type_a_value_between") + " [1-60]", "Oops",
							JOptionPane.ERROR_MESSAGE);
					allOptionsRight = false;
				}
			} catch (Exception f) {
				JOptionPane.showMessageDialog(this,
						bundle.getString("type_correctly_questions_and_seconds"),
						"Oops", JOptionPane.ERROR_MESSAGE);
				allOptionsRight = false;

			}			
		}
		while(!allOptionsRight);
		
		applet.setSecondsPerQuestion(seconds);
		applet.setTotalQuestions(questionsNumber);
		
		if (!secondsJCheckBox.isSelected())
			applet.timeJLabel.setText("X");	
		else
			applet.timeJLabel.setText(secondsJTextField.getText());
		
		if(mode1RadioButton.isSelected())
		{
			applet.setQuestionJLabelText(bundle.getString("which_is_the_symbol_of_this_element"));
			applet.setElementJLabelText(bundle.getString("element").toUpperCase());
		}
		else if(mode2RadioButton.isSelected())
		{
			applet.setQuestionJLabelText(bundle.getString("which_element_has_this_symbol"));
			applet.setElementJLabelText(bundle.getString("symbol").toUpperCase());			
		}
		else if(mode3RadioButton.isSelected())
		{
			applet.setQuestionJLabelText(bundle.getString("which_atomic_number_has_this_element"));
			applet.setElementJLabelText("E / S");			
		}
		else
		{
			applet.setQuestionJLabelText(bundle.getString("which_element_has_this_atomic_number"));
			applet.setElementJLabelText(bundle.getString("atomic_number").toUpperCase());				
		}
		
		if(languagesJComboBox.getSelectedIndex() == 0)
			Utils.getProperties().setProperty("language", "ca_ES");
		else if(languagesJComboBox.getSelectedIndex() == 1)
			Utils.getProperties().setProperty("language", "en_US");
		else if(languagesJComboBox.getSelectedIndex() == 2)
			Utils.getProperties().setProperty("language", "es_ES");
		else if(languagesJComboBox.getSelectedIndex() == 3)
			Utils.getProperties().setProperty("language", "fr_FR");
		
		if(mode1RadioButton.isSelected())
			Utils.getProperties().setProperty("mode", "1");
		else if(mode2RadioButton.isSelected())
			Utils.getProperties().setProperty("mode", "2");
		else if(mode3RadioButton.isSelected())
			Utils.getProperties().setProperty("mode", "3");
		else
			Utils.getProperties().setProperty("mode", "4");
		
		Utils.getProperties().setProperty("seconds",secondsJTextField.getText());
		Utils.getProperties().setProperty("questions", questionsNumberJTextField.getText());
		Utils.getProperties().setProperty("allow_blank_answers", blankAnswersJCheckBox.isSelected() ? "true" : "false");
		Utils.getProperties().setProperty("show_correct_answers", showCorrectAnswersJCheckBox.isEnabled() ? "true" : "false");
		Utils.getProperties().setProperty("seconds_enabled", secondsJCheckBox.isEnabled() ? "true" : "false");
	}
	
	private void changeLanguage()
	{
		bundle = Utils.getBundle();
		
		mode1RadioButton.setText(bundle.getString("mode") + " 1");
		mode2RadioButton.setText(bundle.getString("mode") + " 2");
		mode3RadioButton.setText(bundle.getString("mode") + " 3");
		mode4RadioButton.setText(bundle.getString("mode") + " 4");
		secondsJCheckBox.setText(bundle.getString("seconds_to_answer") + " [1-60]");
		showCorrectAnswersJCheckBox.setText(bundle.getString("show_correct_answers"));
		blankAnswersJCheckBox.setText(bundle.getString("allow_blank_answers"));
		questionsNumberJLabel.setText(bundle.getString("questions_number") + " [1-112]");
	}
	
	public JTextField getSecondsJTextField() {
		return secondsJTextField;
	}
	
	public JTextField getQuestionsNumberJTextField() {
		return questionsNumberJTextField;
	}
}
